const Chance = require('chance')
const {
  submittingAuthor,
  reviewer,
  answerReviewer,
  recReviewer,
  handlingEditor,
  admin,
  inactiveReviewer,
} = require('./userData')
const { standardCollID } = require('./collectionIDs')
const { user } = require('./userData')

const chance = new Chance()
const fragments = {
  fragment: {
    id: chance.guid(),
    collectionId: standardCollID,
    metadata: {
      title: chance.sentence(),
      abstract: chance.paragraph(),
    },
    recommendations: [
      {
        recommendation: 'publish',
        recommendationType: 'review',
        comments: [
          {
            content: chance.paragraph(),
            public: chance.bool(),
            files: [
              {
                id: chance.guid(),
                name: 'file.pdf',
                size: chance.natural(),
              },
            ],
          },
        ],
        id: chance.guid(),
        userId: recReviewer.id,
        createdOn: chance.timestamp(),
        updatedOn: chance.timestamp(),
      },
      {
        recommendation: 'minor',
        recommendationType: 'editorRecommendation',
        comments: [
          {
            content: chance.paragraph(),
            public: true,
            files: [
              {
                id: chance.guid(),
                name: 'file.pdf',
                size: chance.natural(),
              },
            ],
          },
        ],
        id: chance.guid(),
        userId: handlingEditor.id,
        createdOn: chance.timestamp(),
        updatedOn: chance.timestamp(),
      },
      {
        recommendation: 'publish',
        recommendationType: 'editorRecommendation',
        comments: [
          {
            content: chance.paragraph(),
            public: chance.bool(),
            files: [
              {
                id: chance.guid(),
                name: 'file.pdf',
                size: chance.natural(),
              },
            ],
          },
        ],
        id: chance.guid(),
        userId: admin.id,
        createdOn: chance.timestamp(),
        updatedOn: chance.timestamp(),
      },
    ],
    authors: [
      {
        email: chance.email(),
        id: submittingAuthor.id,
        isSubmitting: true,
        isCorresponding: false,
      },
      {
        email: inactiveReviewer.email,
        id: inactiveReviewer.id,
        isSubmitting: false,
        isCorresponding: false,
      },
    ],
    invitations: [
      {
        id: chance.guid(),
        role: 'reviewer',
        hasAnswer: false,
        isAccepted: false,
        userId: reviewer.id,
        invitedOn: chance.timestamp(),
        respondedOn: null,
        type: 'invitation',
      },
      {
        id: chance.guid(),
        role: 'reviewer',
        hasAnswer: true,
        isAccepted: false,
        userId: answerReviewer.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
        type: 'invitation',
      },
      {
        id: chance.guid(),
        role: 'reviewer',
        hasAnswer: false,
        isAccepted: false,
        userId: inactiveReviewer.id,
        invitedOn: chance.timestamp(),
        respondedOn: chance.timestamp(),
        type: 'invitation',
      },
    ],
    save: jest.fn(() => fragments.fragment),
    owners: [user.id],
    type: 'fragment',
    revision: {
      collectionId: standardCollID,
      metadata: {
        title: chance.sentence(),
        abstract: chance.paragraph(),
      },
      authors: [
        {
          email: chance.email(),
          id: submittingAuthor.id,
          isSubmitting: true,
          isCorresponding: false,
        },
      ],
      owners: [user.id],
      type: 'fragment',
    },
  },
  noParentFragment: {
    id: chance.guid(),
    collectionId: '',
    metadata: {
      title: chance.sentence(),
      abstract: chance.paragraph(),
    },
    authors: [
      {
        email: chance.email(),
        id: submittingAuthor.id,
        isSubmitting: true,
        isCorresponding: false,
      },
    ],
    save: jest.fn(() => fragments.fragment),
    owners: [user.id],
    type: 'fragment',
  },
}

module.exports = fragments
